/**
 * @class TheTmp
 */
'use strict'

const tmp = require('tmp')

/** @lends TheTmp */
class TheTmp {
  /**
   * Create tmp file
   * @param {function} handler - Handler function to use tmp file
   * @param {Object} options - Tmp options
   * @returns {Promise<*>}
   */
  async file (handler, options = {}) {
    return new Promise((resolve, reject) => {
      tmp.file(options, (err, filename, descriptor, cleanupCallback) => {
        if (err) {
          reject(err)
          return
        }
        Promise.resolve(handler(filename, descriptor))
          .then((resolved) => {
            resolve(resolved)
            cleanupCallback()
          })
          .catch((e) => {
            cleanupCallback()
            reject(e)
          })
      })
    })
  }
}

module.exports = TheTmp
